#delimit;
clear;
cap log close;
set mem 300m;
set more 1;
set matsize 600;
set trace off;

/* CHANGE THIS LINE TO REFLECT LOCAL DIRECTORY STRUCTURE */;
global REPDIR ="C:\Users\ecascardi\Dropbox\ELISA\TED\RESEARCH\PoliComp&EthnId Data Replication 2\PoliComp&EthnId Data Replication";
cd "$REPDIR";
use EthnicId_Data;

log using ethnic_id-LOG, replace text;

***-----------------------------------------------------------------------------------------------------------------------------------------------------;
* Primary analysis
***-----------------------------------------------------------------------------------------------------------------------------------------------------;

/* TABLE 1: Economic and Political Characteristics of Sample Countries;

This gives the two last columns. Signs (+/-) are different from those in Paper.; 
No sign of the first column in this do file*/;
	table country_round, c( mean elec_prox mean elec_comp);


/* TABLE 2: ranking of different identities over survey-rounds;

PROBLEM: Table 2 was given by :tab country_round identity_cat in the original do file; tab returns;
frequencies. I something different in order to obtain frequencies. Only problem is I don't have "no answer"*/;
	sort country_round;
	by country_round: tab identity_cat, missing;

*** Drop countries with one round and people who didn't answer the main question;
	drop if identity_cat == 6;
	drop if panel_dataset == 0;
	drop if primary_data == 0;
	drop if age == 0;

*** Generate binary ethnic identification variable;
	gen ethnic = 0 if identity_cat != .;
	replace ethnic = 1 if identity_cat == 1;
	
/* TABLE 3: Political Determinants of Ethnic Identification*/;
/*note: column 4 is at the end of the do file due to 'collapse' command.*/
	xi: logit ethnic elec_prox elec_comp trend i.round i.country [pweight=1/survey_weight], cluster(country_round);
/* Table 3 column 1*/;
	mfx, varlist(elec_prox elec_comp);
	xi: logit ethnic elec_prox elec_comp prox_comp trend i.round i.country [pweight=1/survey_weight], cluster(country_round);
/* Table 3 column 2*/;
	mfx, varlist(elec_prox elec_comp prox_comp);
	xi: logit ethnic elec_prox elec_comp prox_comp male age urban radio_daily newspaper_weekly educ_primary educ_secondary educ_postsec trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country [pweight=1/survey_weight], cluster(country_round);
/* Table 3 column 3*/;
	mfx, varlist(elec_prox elec_comp prox_comp);


/* TABLE 4: Determinants of Ethnic and Other Social Identities */;

	xi: mlogit identity_cat elec_prox elec_comp prox_comp farmer_fisherman lang_d_10 ruling_party radio_daily youth_male trend i.round i.country [pweight=1/survey_weight], cluster(country_round) iterate(15) baseoutcome(3);
/*Table 4 column 1 "Ethnicity"*/;
		mfx, varlist(elec_prox elec_comp prox_comp farmer_fisherman lang_d_10 ruling_party youth_male) predict(p outcome(1)); 
/*Table 4 column 2 "Class/Occupation"*/;
		mfx, varlist(elec_prox elec_comp prox_comp lang_d_10 ruling_party youth_male) predict(p outcome(2)); 
/*Table 4 column 3 "Religion"*/;
		mfx, varlist(elec_prox elec_comp prox_comp lang_d_10 ruling_party youth_male) predict(p outcome(3));
/*Table 4 column 4 "Gender"*/;
		mfx, varlist(elec_prox elec_comp prox_comp lang_d_10 ruling_party youth_male) predict(p outcome(4)); 
/*Table 4 column 5 "Other"*/;
		mfx, varlist(elec_prox elec_comp prox_comp lang_d_10 ruling_party youth_male) predict(p outcome(5)); 
		
		/*test ([1] elec_prox elec_comp prox_comp) ([2] elec_prox elec_comp prox_comp) ([4] elec_prox elec_comp prox_comp) ([5] elec_prox elec_comp prox_comp)*/;

*** Back to Table 3, country-round as unit of observation;
*** Do last as requires collapsing dataset;	
	collapse(mean) identity_ethnic_1 identity_religion identity_occupation identity_gender identity_other_1 elec_prox elec_comp prox_comp year round trend country, by(country_round);
/* Table 3 column 4*/;	
	xi: reg (identity_ethnic_1 elec_prox elec_comp prox_comp i.round trend i.country)
	
	/* if you would like to look at this OLS (country level for other type of identity (religion/gender/other) then you could run:
		xi: sureg 	(identity_religion elec_prox elec_comp prox_comp i.round trend i.country)
			(identity_gender elec_prox elec_comp prox_comp i.round trend i.country)
			(identity_other_1 elec_prox elec_comp prox_comp i.round trend i.country), small dfk;
			
	/*test [identity_ethnic_1] elec_prox elec_comp prox_comp [identity_religion] elec_prox elec_comp prox_comp 
	[identity_gender] elec_prox elec_comp prox_comp	[identity_other_1] elec_prox elec_comp prox_comp;

		mfx, predict(outcome(identity_ethnic_1));
		mfx, predict(outcome(identity_religion));
		mfx, predict(outcome(identity_gender));
		mfx, predict(outcome(identity_other_1));*/
		
*** Appendix Table 1;
***	tabstat LPCI elec_prox elec_comp urban male age radio_daily newspaper_weekly educ_none educ_prim educ_sec educ_post 
***	farmer trader white_c blue_c student unemployed emp_other hardship, stats(mean sd n);

log c;

exit;

***-----------------------------------------------------------------------------------------------------------------------------------------------------;
* Robustness checks and old tables; comment out "exit" above if you want to run this;
***-----------------------------------------------------------------------------------------------------------------------------------------------------;

use "ab_r1_r15_r2.dta", clear;

*** Drop countries with one round and people who didn't answer the main question;
	drop if identity_cat == 6;
	drop if panel_dataset == 0;
	drop if primary_data == 0;
	drop if age == 0;

*** Generate binary ethnic identification variable;
	gen ethnic = 0 if identity_cat != .;
	replace ethnic = 1 if identity_cat == 1;

*** Old Table 5, logit and multinomial logit with key interactions;

	* Basic;

		xi: mlogit identity_cat elec_prox elec_comp prox_comp male age urban radio_daily educ_primary educ_secondary educ_postsec trader_business white_collar blue_collar student emp_other hardship newspaper_weekly ep_newsp ec_newsp pc_newsp lang_d_biggest ep_lang_d_biggest ec_lang_d_biggest pc_lang_d_biggest lang_d_10 ep_lang_d_10 ec_lang_d_10 pc_lang_d_10 ruling_party ep_ruling_party ec_ruling_party pc_ruling_party opposition_party ep_opposition_party ec_opposition_party pc_opposition_party unemployed ep_unemp ec_unemp pc_unemp trend i.round i.country [pweight=1/survey_weight], cluster(country_round) iterate(15) baseoutcome(3);
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(1)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(2)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(3)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(4)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(5)); 

	* Ethnic definition inclusive of political alliances;

		xi: mlogit identity_cat elec_prox elec_comp prox_comp newspaper_weekly ep_newsp ec_newsp pc_newsp lang_d_biggest ep_lang_d_biggest ec_lang_d_biggest pc_lang_d_biggest lang_a_10 ep_lang_a_10 ec_lang_a_10 pc_lang_a_10 ruling_party ep_ruling_party ec_ruling_party pc_ruling_party opposition_party ep_opposition_party ec_opposition_party pc_opposition_party unemployed ep_unemp ec_unemp pc_unemp trend i.round i.country [pweight=1/survey_weight], cluster(country_round) iterate(15) baseoutcome(3);
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(1)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(2));
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(3)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(4)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(5));

	* Unemployed youth only;

		xi: mlogit identity_cat elec_prox elec_comp prox_comp newspaper_weekly ep_newsp ec_newsp pc_newsp lang_d_biggest ep_lang_d_biggest ec_lang_d_biggest pc_lang_d_biggest lang_d_10 ep_lang_d_10 ec_lang_d_10 pc_lang_d_10 ruling_party ep_ruling_party ec_ruling_party pc_ruling_party opposition_party ep_opposition_party ec_opposition_party pc_opposition_party unemployed trend i.round i.country [pweight=1/survey_weight] if unemp == 1 & youth == 1, cluster(country_round) iterate(15) baseoutcome(3);
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(1)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(2)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(3)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(4)); 
		mfx, varlist(elec_prox elec_comp prox_comp) predict(p outcome(5));


* ROBUSTNESS CHECKS: 

	* add LPCI;	xi: mlogit identity_cat elec_prox elec_comp prox_comp LPCI male age urban radio_daily newspaper_weekly educ_primary educ_secondary educ_postsec trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country [pweight=1/survey_weight], cluster(country_round) iterate(15) baseoutcome(3);

	* Table 4 with the bootstrap;
		xi: bootstrap [1]_se[elec_prox] [1]_se[elec_comp] [1]_se[prox_comp] [2]_se[elec_prox] [2]_se[elec_comp] [2]_se[prox_comp] [3]_se[elec_prox] [3]_se[elec_comp] [3]_se[prox_comp] [4]_se[elec_prox] [4]_se[elec_comp] [4]_se[prox_comp] [5]_se[elec_prox] [5]_se[elec_comp] [5]_se[prox_comp], reps(3) noisily: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country, cluster(country) iterate(15) baseoutcome(3);


* ROBUSTNESS CHECKS: drop countries one at a time, plus Botswana Tanzania Zimbabwe all at once;

	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country if country_name ~= "Botswana"	[pweight = 1/survey_weight], robust cluster(country_round) iterate(15) baseoutcome(3);
	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country if country_name ~= "Malawi" [pweight = 1/survey_weight], robust cluster(country_round) iterate(15)  baseoutcome(3);
	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country if country_name ~= "Mali" [pweight = 1/survey_weight], robust cluster(country_round) iterate(15)  baseoutcome(3);
	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country if country_name ~= "Namibia" [pweight = 1/survey_weight], robust cluster(country_round) iterate(15)  baseoutcome(3);
	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country if country_name ~= "Nigeria" [pweight = 1/survey_weight], robust cluster(country_round) iterate(15) baseoutcome(3);
	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country if country_name ~= "SouthAfrica" [pweight = 1/survey_weight], robust cluster(country_round) iterate(15) baseoutcome(3);
	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country if country_name ~= "Tanzania" [pweight = 1/survey_weight], robust cluster(country_round) iterate(15) baseoutcome(3);
	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country if country_name ~= "Uganda" [pweight = 1/survey_weight], robust cluster(country_round) iterate(15) baseoutcome(3);
	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country if country_name ~= "Zambia" [pweight = 1/survey_weight], robust cluster(country_round) iterate(15) baseoutcome(3);
	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round i.country if country_name ~= "Zimbabwe" [pweight = 1/survey_weight], robust cluster(country_round) iterate(15) baseoutcome(3);

	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round male age urban radio_daily newspaper_weekly educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship i.country if country_name ~= "Zimbabwe" & country_name != "Botswana" & country_name != "Tanzania"
	[pweight = 1/survey_weight], robust cluster(country_round) iterate(15) baseoutcome(3);

	xi: mlogit identity_cat elec_prox elec_comp prox_comp trend i.round male age urban radio_daily newspaper_weekly educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship i.country if country_name ~= "Mali" & country_name != "Malawi" & country_name != "Zambia"
	[pweight = 1/survey_weight], robust cluster(country_round) iterate(15) baseoutcome(3);


* ROBUSTNESS CHECKS: Run with race included in other instead of ethnic;

	xi: mlogit identity_cat_2 elec_prox elec_comp prox_comp male age urban radio_daily newspaper_weekly interested_politics educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country [pweight=1/survey_weight], cluster(country_round) iterate(15) baseoutcome(3);


* ROBUSTNESS CHECKS: Run with interview characteristics;

	xi: mlogit identity_cat elec_prox elec_comp prox_comp male age urban radio_daily newspaper_weekly interested_politics educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country i.others_listening i.others_consulted i.others_influenced i.share_difficult i.friendly i.interested i.cooperative i.patient i.at_ease
	i.honest i.threatened [pweight=1/survey_weight] if int_data == 1, cluster(country_round) iterate(15) baseoutcome(3);


* ROBUSTNESS CHECKS: Run with interview and enumerator characteristics;

	xi: mlogit identity_cat elec_prox elec_comp prox_comp male age urban radio_daily newspaper_weekly interested_politics educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country i.others_listening i.others_consulted i.others_influenced i.share_difficult i.friendly i.interested i.cooperative
	i.patient i.at_ease i.honest i.threatened enum_age i.enum_urban i.enum_gender i.enum_educ [pweight=1/survey_weight] if int_data == 1, cluster(country_round) iterate(15) baseoutcome(3);


* HETEROGENEITY CHECKS: Run separately for men/women and urban/rural;

	xi: mlogit identity_cat elec_prox elec_comp prox_comp male age urban radio_daily newspaper_weekly interested_politics educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country [pweight=1/survey_weight] if male == 1, cluster(country_round) iterate(15) baseoutcome(3);

	xi: mlogit identity_cat elec_prox elec_comp prox_comp male age urban radio_daily newspaper_weekly interested_politics educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country [pweight=1/survey_weight] if male == 0, cluster(country_round) iterate(15) baseoutcome(3);

	xi: mlogit identity_cat elec_prox elec_comp prox_comp male age urban radio_daily newspaper_weekly interested_politics educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country [pweight=1/survey_weight] if male == 1 & urban == 1, cluster(country_round) iterate(15) baseoutcome(3);

	xi: mlogit identity_cat elec_prox elec_comp prox_comp male age urban radio_daily newspaper_weekly interested_politics educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country [pweight=1/survey_weight] if male == 1 & urban == 0, cluster(country_round) iterate(15) baseoutcome(3);

	xi: mlogit identity_cat elec_prox elec_comp prox_comp male age urban radio_daily newspaper_weekly interested_politics educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country [pweight=1/survey_weight] if male == 0 & urban == 1, cluster(country_round) iterate(15) baseoutcome(3);

	xi: mlogit identity_cat elec_prox elec_comp prox_comp male age urban radio_daily newspaper_weekly interested_politics educ_primary educ_secondary educ_postsec
	trader_business white_collar blue_collar unemployed student emp_other hardship trend i.round i.country [pweight=1/survey_weight] if male == 0 & urban == 0, cluster(country_round) iterate(15) baseoutcome(3);



